@@ -479,7 +479,7 @@ int main(int argc, char *argv[])
     // Ensure quit on last window close
     // Register main DCOP interface
     //
-    TQObject::connect(&app, TQT_SIGNAL(lastWindowClosed()), &app, TQT_SLOT(quit()));
+    TQObject::connect(&app, TQ_SIGNAL(lastWindowClosed()), &app, TQ_SLOT(quit()));
     app.dcopClient()->registerAs(app.name(), false);
     app.dcopClient()->setDefaultObject(ROSEGARDEN_GUI_IFACE_NAME);
 
@@ -594,7 +594,7 @@ int main(int argc, char *argv[])
 
         rosegardengui = new RosegardenGUIApp(!app.noSequencerMode(),
                                              args->isSet("existingsequencer"),
-                                             TQT_TQOBJECT(startLogo));
+                                             startLogo);
 
 	rosegardengui->setIsFirstRun(newVersion);
 
@@ -624,8 +624,8 @@ int main(int argc, char *argv[])
 
     }
 
-    TQObject::connect(&app, TQT_SIGNAL(aboutToSaveState()),
-                     rosegardengui, TQT_SLOT(slotDeleteTransport()));
+    TQObject::connect(&app, TQ_SIGNAL(aboutToSaveState()),
+                     rosegardengui, TQ_SLOT(slotDeleteTransport()));
 
     // Now that we've started up, raise start logo
     //
@@ -661,8 +661,8 @@ int main(int argc, char *argv[])
             (*sfxLoadProcess) << sfxLoadPath << soundFontPath;
             RG_DEBUG << "Starting sfxload : " << sfxLoadPath << " " << soundFontPath << endl;
 
-            TQObject::connect(sfxLoadProcess, TQT_SIGNAL(processExited(TDEProcess*)),
-                             &app, TQT_SLOT(sfxLoadExited(TDEProcess*)));
+            TQObject::connect(sfxLoadProcess, TQ_SIGNAL(processExited(TDEProcess*)),
+                             &app, TQ_SLOT(sfxLoadExited(TDEProcess*)));
 
             sfxLoadProcess->start();
         } else {
@@ -694,7 +694,7 @@ int main(int argc, char *argv[])
 
         if (visibleFor < RealTime(2, 0)) {
             int waitTime = visibleFor.sec * 1000 + visibleFor.msec();
-            TQTimer::singleShot(2500 - waitTime, startLogo, TQT_SLOT(close()));
+            TQTimer::singleShot(2500 - waitTime, startLogo, TQ_SLOT(close()));
         } else {
             startLogo->close();
         }
