@@ -127,48 +127,48 @@ AudioManagerDialog::AudioManagerDialog(TQWidget *parent,
     TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/transport-play.xpm"));
 
-    new TDEAction(i18n("&Add Audio File..."), "document-open", 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotAdd()), actionCollection(), "add_audio");
+    new TDEAction(i18n("&Add Audio File..."), "document-open", 0, this,
+                TQ_SLOT(slotAdd()), actionCollection(), "add_audio");
 
-    new TDEAction(i18n("&Unload Audio File"), "edit-delete", 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRemove()),
+    new TDEAction(i18n("&Unload Audio File"), "edit-delete", 0, this,
+                TQ_SLOT(slotRemove()),
                 actionCollection(), "remove_audio");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/transport-play.xpm"));
-    new TDEAction(i18n("&Play Preview"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotPlayPreview()),
+    new TDEAction(i18n("&Play Preview"), icon, 0, this,
+                TQ_SLOT(slotPlayPreview()),
                 actionCollection(), "preview_audio");
 
     /*!!! Not actually implemented -- this never worked right!
-        new TDEAction(i18n("Re&label"), 0, 0, TQT_TQOBJECT(this),
-    		TQT_SLOT(slotRename()), 
+        new TDEAction(i18n("Re&label"), 0, 0, this,
+    		TQ_SLOT(slotRename()), 
     		actionCollection(), "rename_audio");
     */
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/insert_audio_into_track.xpm"));
     new TDEAction(i18n("&Insert into Selected Audio Track"),
-                icon, 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsert()),
+                icon, 0, this, TQ_SLOT(slotInsert()),
                 actionCollection(), "insert_audio");
 
-    new TDEAction(i18n("Unload &all Audio Files"), 0, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRemoveAll()),
+    new TDEAction(i18n("Unload &all Audio Files"), 0, 0, this,
+                TQ_SLOT(slotRemoveAll()),
                 actionCollection(), "remove_all_audio");
 
-    new TDEAction(i18n("Unload all &Unused Audio Files"), 0, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRemoveAllUnused()),
+    new TDEAction(i18n("Unload all &Unused Audio Files"), 0, 0, this,
+                TQ_SLOT(slotRemoveAllUnused()),
                 actionCollection(), "remove_all_unused_audio");
 
-    new TDEAction(i18n("&Delete Unused Audio Files..."), 0, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDeleteUnused()),
+    new TDEAction(i18n("&Delete Unused Audio Files..."), 0, 0, this,
+                TQ_SLOT(slotDeleteUnused()),
                 actionCollection(), "delete_unused_audio");
 
-    new TDEAction(i18n("&Export Audio File..."), "fileexport", 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotExportAudio()),
+    new TDEAction(i18n("&Export Audio File..."), "fileexport", 0, this,
+                TQ_SLOT(slotExportAudio()),
                 actionCollection(), "export_audio");
 /*
     new TDEAction(i18n("Distribute Audio on &MIDI"),
-                0, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDistributeOnMidiSegment()),
+                0, 0, this,
+                TQ_SLOT(slotDistributeOnMidiSegment()),
                 actionCollection(),
                 "distribute_audio");
 */
@@ -200,11 +200,11 @@ AudioManagerDialog::AudioManagerDialog(TQWidget *parent,
     m_fileList->setShowToolTips(true);
 
     // connect selection mechanism
-    connect(m_fileList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-            TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
+    connect(m_fileList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+            TQ_SLOT(slotSelectionChanged(TQListViewItem*)));
 
-    connect(m_fileList, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)),
-            TQT_SLOT(slotDropped(TQDropEvent*, TQListViewItem*)));
+    connect(m_fileList, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)),
+            TQ_SLOT(slotDropped(TQDropEvent*, TQListViewItem*)));
 
     // setup local accelerators
     //
@@ -214,22 +214,22 @@ AudioManagerDialog::AudioManagerDialog(TQWidget *parent,
     //
     m_accelerators->connectItem(m_accelerators->insertItem(Key_Delete),
                                 this,
-                                TQT_SLOT(slotRemove()));
+                                TQ_SLOT(slotRemove()));
 
     slotPopulateFileList();
 
     // Connect command history for updates
     //
-    connect(getCommandHistory(), TQT_SIGNAL(commandExecuted(KCommand *)),
-            this, TQT_SLOT(slotCommandExecuted(KCommand *)));
+    connect(getCommandHistory(), TQ_SIGNAL(commandExecuted(KCommand *)),
+            this, TQ_SLOT(slotCommandExecuted(KCommand *)));
 
     //setInitialSize(configDialogSize(AudioManagerDialogConfigGroup));
 
-    connect(m_playTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotCancelPlayingAudio()));
+    connect(m_playTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotCancelPlayingAudio()));
 
-    KStdAction::close(TQT_TQOBJECT(this),
-                      TQT_SLOT(slotClose()),
+    KStdAction::close(this,
+                      TQ_SLOT(slotClose()),
                       actionCollection());
 
     createGUI("audiomanager.rc");
@@ -1091,12 +1091,12 @@ AudioManagerDialog::addFile(const KURL& kurl)
 
     // Connect the progress dialog
     //
-    connect(&aFM, TQT_SIGNAL(setProgress(int)),
-            progressDlg.progressBar(), TQT_SLOT(setValue(int)));
-    connect(&aFM, TQT_SIGNAL(setOperationName(TQString)),
-            &progressDlg, TQT_SLOT(slotSetOperationName(TQString)));
-    connect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-            &aFM, TQT_SLOT(slotStopImport()));
+    connect(&aFM, TQ_SIGNAL(setProgress(int)),
+            progressDlg.progressBar(), TQ_SLOT(setValue(int)));
+    connect(&aFM, TQ_SIGNAL(setOperationName(TQString)),
+            &progressDlg, TQ_SLOT(slotSetOperationName(TQString)));
+    connect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+            &aFM, TQ_SLOT(slotStopImport()));
 
     try {
         id = aFM.importURL(kurl, m_sampleRate);
@@ -1112,10 +1112,10 @@ AudioManagerDialog::addFile(const KURL& kurl)
         return false;
     }
             
-    disconnect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-               &aFM, TQT_SLOT(slotStopImport()));
-    connect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-            &aFM, TQT_SLOT(slotStopPreview()));
+    disconnect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+               &aFM, TQ_SLOT(slotStopImport()));
+    connect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+            &aFM, TQ_SLOT(slotStopPreview()));
     progressDlg.progressBar()->show();
     progressDlg.slotSetOperationName(i18n("Generating audio preview..."));
 
@@ -1129,8 +1129,8 @@ AudioManagerDialog::addFile(const KURL& kurl)
         KMessageBox::information(this, message);
     }
 
-    disconnect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-               &aFM, TQT_SLOT(slotStopPreview()));
+    disconnect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+               &aFM, TQ_SLOT(slotStopPreview()));
 
     slotPopulateFileList();
 
