@@ -36,7 +36,7 @@ namespace Rosegarden
 
 class ShowSequencerStatusDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ShowSequencerStatusDialog(TQWidget *parent);
