@@ -50,8 +50,8 @@ GuitarChordEditorDialog::GuitarChordEditorDialog(Guitar::Chord& chord, const Gui
     m_startFret = new TQSpinBox(1, 24, 1, page);
     topLayout->addWidget(m_startFret, 1, 1);
     
-    connect(m_startFret, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SLOT(slotStartFretChanged(int)));
+    connect(m_startFret, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotStartFretChanged(int)));
     
     topLayout->addWidget(new TQLabel(i18n("Root"), page), 2, 1);
     m_rootNotesList = new TQComboBox(page);
