@@ -69,19 +69,19 @@ MatrixSelector::MatrixSelector(MatrixView* view)
         m_matrixView(view),
         m_selectionToMerge(0)
 {
-    connect(m_parentView, TQT_SIGNAL(usedSelection()),
-            this, TQT_SLOT(slotHideSelection()));
+    connect(m_parentView, TQ_SIGNAL(usedSelection()),
+            this, TQ_SLOT(slotHideSelection()));
 
     new TDEAction(i18n("Switch to Draw Tool"), "pencil", 0, this,
-                TQT_SLOT(slotDrawSelected()), actionCollection(),
+                TQ_SLOT(slotDrawSelected()), actionCollection(),
                 "draw");
 
     new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
-                TQT_SLOT(slotEraseSelected()), actionCollection(),
+                TQ_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
     new TDEAction(i18n("Switch to Move Tool"), "move", 0, this,
-                TQT_SLOT(slotMoveSelected()), actionCollection(),
+                TQ_SLOT(slotMoveSelected()), actionCollection(),
                 "move");
 
     TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
@@ -89,7 +89,7 @@ MatrixSelector::MatrixSelector(MatrixView* view)
     TQIconSet icon = TQIconSet(pixmap);
 
     new TDEAction(i18n("Switch to Resize Tool"), icon, 0, this,
-                TQT_SLOT(slotResizeSelected()), actionCollection(),
+                TQ_SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
 
     createMenu("matrixselector.rc");
@@ -316,7 +316,7 @@ void MatrixSelector::handleMouseDoubleClick(timeT ,
     	
     	m_justSelectedBar = true;
     	TQTimer::singleShot(TQApplication::doubleClickInterval(), this,
-    			   TQT_SLOT(slotClickTimeout()));
+    			   TQ_SLOT(slotClickTimeout()));
         } */
 }
 
@@ -445,8 +445,8 @@ void MatrixSelector::ready()
         //m_mParentView->setPositionTracking(false);
     }
 
-    connect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
-            this, TQT_SLOT(slotMatrixScrolled(int, int)));
+    connect(m_parentView->getCanvasView(), TQ_SIGNAL(contentsMoving (int, int)),
+            this, TQ_SLOT(slotMatrixScrolled(int, int)));
 
     setContextHelp(i18n("Click and drag to select; middle-click and drag to draw new note"));
 }
@@ -459,8 +459,8 @@ void MatrixSelector::stow()
         m_mParentView->canvas()->update();
     }
 
-    disconnect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
-               this, TQT_SLOT(slotMatrixScrolled(int, int)));
+    disconnect(m_parentView->getCanvasView(), TQ_SIGNAL(contentsMoving (int, int)),
+               this, TQ_SLOT(slotMatrixScrolled(int, int)));
 
 }
 
