@@ -173,14 +173,14 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
                            KDockWidget::DockLeft,  // dock site
                            20);                   // relation target/this (in percent)
 
-    connect(m_dockLeft, TQT_SIGNAL(iMBeingClosed()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotParametersClosed()));
-    connect(m_dockLeft, TQT_SIGNAL(hasUndocked()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotParametersClosed()));
+    connect(m_dockLeft, TQ_SIGNAL(iMBeingClosed()),
+            this, TQ_SLOT(slotParametersClosed()));
+    connect(m_dockLeft, TQ_SIGNAL(hasUndocked()),
+            this, TQ_SLOT(slotParametersClosed()));
     // Apparently, hasUndocked() is emitted when the dock widget's
     // 'close' button on the dock handle is clicked.
-    connect(m_mainDockWidget, TQT_SIGNAL(docking(KDockWidget*, KDockWidget::DockPosition)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotParametersDockedBack(KDockWidget*, KDockWidget::DockPosition)));
+    connect(m_mainDockWidget, TQ_SIGNAL(docking(KDockWidget*, KDockWidget::DockPosition)),
+            this, TQ_SLOT(slotParametersDockedBack(KDockWidget*, KDockWidget::DockPosition)));
 
     Composition &comp = doc->getComposition();
 
@@ -188,10 +188,10 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     initStatusBar();
 
-    connect(m_toolBox, TQT_SIGNAL(showContextHelp(const TQString &)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotToolHelpChanged(const TQString &)));
+    connect(m_toolBox, TQ_SIGNAL(showContextHelp(const TQString &)),
+            this, TQ_SLOT(slotToolHelpChanged(const TQString &)));
 
-    TQCanvas *tCanvas = new TQCanvas(TQT_TQOBJECT(this));
+    TQCanvas *tCanvas = new TQCanvas(this);
 
     m_config->setGroup(MatrixViewConfigGroup);
     if (m_config->readBoolEntry("backgroundtextures-1.6-plus", true)) {
@@ -276,33 +276,33 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     RosegardenGUIApp *app = RosegardenGUIApp::self();
     connect(app,
-            TQT_SIGNAL(pluginSelected(InstrumentId, int, int)),
+            TQ_SIGNAL(pluginSelected(InstrumentId, int, int)),
             m_parameterBox,
-            TQT_SLOT(slotPluginSelected(InstrumentId, int, int)));
+            TQ_SLOT(slotPluginSelected(InstrumentId, int, int)));
     connect(app,
-            TQT_SIGNAL(pluginBypassed(InstrumentId, int, bool)),
+            TQ_SIGNAL(pluginBypassed(InstrumentId, int, bool)),
             m_parameterBox,
-            TQT_SLOT(slotPluginBypassed(InstrumentId, int, bool)));
+            TQ_SLOT(slotPluginBypassed(InstrumentId, int, bool)));
     connect(app,
-            TQT_SIGNAL(instrumentParametersChanged(InstrumentId)),
+            TQ_SIGNAL(instrumentParametersChanged(InstrumentId)),
             m_parameterBox,
-            TQT_SLOT(slotInstrumentParametersChanged(InstrumentId)));
+            TQ_SLOT(slotInstrumentParametersChanged(InstrumentId)));
     connect(m_parameterBox,
-            TQT_SIGNAL(instrumentParametersChanged(InstrumentId)),
+            TQ_SIGNAL(instrumentParametersChanged(InstrumentId)),
             app,
-            TQT_SIGNAL(instrumentParametersChanged(InstrumentId)));
+            TQ_SIGNAL(instrumentParametersChanged(InstrumentId)));
     connect(m_parameterBox,
-            TQT_SIGNAL(selectPlugin(TQWidget *, InstrumentId, int)),
+            TQ_SIGNAL(selectPlugin(TQWidget *, InstrumentId, int)),
             app,
-            TQT_SLOT(slotShowPluginDialog(TQWidget *, InstrumentId, int)));
+            TQ_SLOT(slotShowPluginDialog(TQWidget *, InstrumentId, int)));
     connect(m_parameterBox,
-            TQT_SIGNAL(showPluginGUI(InstrumentId, int)),
+            TQ_SIGNAL(showPluginGUI(InstrumentId, int)),
             app,
-            TQT_SLOT(slotShowPluginGUI(InstrumentId, int)));
+            TQ_SLOT(slotShowPluginGUI(InstrumentId, int)));
     connect(parent,  // RosegardenGUIView
-            TQT_SIGNAL(checkTrackAssignments()),
+            TQ_SIGNAL(checkTrackAssignments()),
             this,
-            TQT_SLOT(slotCheckTrackAssignments()));
+            TQ_SLOT(slotCheckTrackAssignments()));
 
     // Assign the instrument
     //
@@ -310,9 +310,9 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     if (m_drumMode) {
         connect(m_parameterBox,
-                TQT_SIGNAL(instrumentPercussionSetChanged(Instrument *)),
+                TQ_SIGNAL(instrumentPercussionSetChanged(Instrument *)),
                 this,
-                TQT_SLOT(slotPercussionSetChanged(Instrument *)));
+                TQ_SLOT(slotPercussionSetChanged(Instrument *)));
     }
 
     // Set the snap grid from the stored size in the segment
@@ -350,83 +350,83 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     // Connect vertical scrollbars between matrix and piano
     //
-    connect(m_canvasView->verticalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
+    connect(m_canvasView->verticalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotVerticalScrollPianoKeyboard(int)));
 
-    connect(m_canvasView->verticalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
+    connect(m_canvasView->verticalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            this, TQ_SLOT(slotVerticalScrollPianoKeyboard(int)));
 
-    connect(m_canvasView, TQT_SIGNAL(zoomIn()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomIn()));
-    connect(m_canvasView, TQT_SIGNAL(zoomOut()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomOut()));
+    connect(m_canvasView, TQ_SIGNAL(zoomIn()), this, TQ_SLOT(slotZoomIn()));
+    connect(m_canvasView, TQ_SIGNAL(zoomOut()), this, TQ_SLOT(slotZoomOut()));
 
-    connect(m_pianoView, TQT_SIGNAL(gotWheelEvent(TQWheelEvent*)),
-            m_canvasView, TQT_SLOT(slotExternalWheelEvent(TQWheelEvent*)));
+    connect(m_pianoView, TQ_SIGNAL(gotWheelEvent(TQWheelEvent*)),
+            m_canvasView, TQ_SLOT(slotExternalWheelEvent(TQWheelEvent*)));
 
     // ensure the piano keyb keeps the right margins when the user toggles
     // the canvas view rulers
     //
-    connect(m_canvasView, TQT_SIGNAL(bottomWidgetHeightChanged(int)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotCanvasBottomWidgetHeightChanged(int)));
+    connect(m_canvasView, TQ_SIGNAL(bottomWidgetHeightChanged(int)),
+            this, TQ_SLOT(slotCanvasBottomWidgetHeightChanged(int)));
 
-    connect(m_canvasView, TQT_SIGNAL(mouseEntered()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotMouseEnteredCanvasView()));
+    connect(m_canvasView, TQ_SIGNAL(mouseEntered()),
+            this, TQ_SLOT(slotMouseEnteredCanvasView()));
 
-    connect(m_canvasView, TQT_SIGNAL(mouseLeft()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotMouseLeftCanvasView()));
+    connect(m_canvasView, TQ_SIGNAL(mouseLeft()),
+            this, TQ_SLOT(slotMouseLeftCanvasView()));
 
     /*
     TQObject::connect
-        (getCanvasView(), TQT_SIGNAL(activeItemPressed(TQMouseEvent*, TQCanvasItem*)),
-         this,            TQT_SLOT  (activeItemPressed(TQMouseEvent*, TQCanvasItem*)));
+        (getCanvasView(), TQ_SIGNAL(activeItemPressed(TQMouseEvent*, TQCanvasItem*)),
+         this,            TQ_SLOT  (activeItemPressed(TQMouseEvent*, TQCanvasItem*)));
          */
 
     TQObject::connect
     (getCanvasView(),
-     TQT_SIGNAL(mousePressed(timeT,
+     TQ_SIGNAL(mousePressed(timeT,
                          int, TQMouseEvent*, MatrixElement*)),
      this,
-     TQT_SLOT(slotMousePressed(timeT,
+     TQ_SLOT(slotMousePressed(timeT,
                            int, TQMouseEvent*, MatrixElement*)));
 
     TQObject::connect
     (getCanvasView(),
-     TQT_SIGNAL(mouseMoved(timeT, int, TQMouseEvent*)),
+     TQ_SIGNAL(mouseMoved(timeT, int, TQMouseEvent*)),
      this,
-     TQT_SLOT(slotMouseMoved(timeT, int, TQMouseEvent*)));
+     TQ_SLOT(slotMouseMoved(timeT, int, TQMouseEvent*)));
 
     TQObject::connect
     (getCanvasView(),
-     TQT_SIGNAL(mouseReleased(timeT, int, TQMouseEvent*)),
+     TQ_SIGNAL(mouseReleased(timeT, int, TQMouseEvent*)),
      this,
-     TQT_SLOT(slotMouseReleased(timeT, int, TQMouseEvent*)));
+     TQ_SLOT(slotMouseReleased(timeT, int, TQMouseEvent*)));
 
     TQObject::connect
-    (getCanvasView(), TQT_SIGNAL(hoveredOverNoteChanged(int, bool, timeT)),
-     TQT_TQOBJECT(this), TQT_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
+    (getCanvasView(), TQ_SIGNAL(hoveredOverNoteChanged(int, bool, timeT)),
+     this, TQ_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
 
     TQObject::connect
-    (m_pitchRuler, TQT_SIGNAL(hoveredOverKeyChanged(unsigned int)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
+    (m_pitchRuler, TQ_SIGNAL(hoveredOverKeyChanged(unsigned int)),
+     this, TQ_SLOT (slotHoveredOverKeyChanged(unsigned int)));
 
     TQObject::connect
-    (m_pitchRuler, TQT_SIGNAL(keyPressed(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeyPressed(unsigned int, bool)));
+    (m_pitchRuler, TQ_SIGNAL(keyPressed(unsigned int, bool)),
+     this, TQ_SLOT (slotKeyPressed(unsigned int, bool)));
 
     TQObject::connect
-    (m_pitchRuler, TQT_SIGNAL(keySelected(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeySelected(unsigned int, bool)));
+    (m_pitchRuler, TQ_SIGNAL(keySelected(unsigned int, bool)),
+     this, TQ_SLOT (slotKeySelected(unsigned int, bool)));
 
     TQObject::connect
-    (m_pitchRuler, TQT_SIGNAL(keyReleased(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeyReleased(unsigned int, bool)));
+    (m_pitchRuler, TQ_SIGNAL(keyReleased(unsigned int, bool)),
+     this, TQ_SLOT (slotKeyReleased(unsigned int, bool)));
 
     TQObject::connect
-    (getCanvasView(), TQT_SIGNAL(hoveredOverAbsoluteTimeChanged(unsigned int)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverAbsoluteTimeChanged(unsigned int)));
+    (getCanvasView(), TQ_SIGNAL(hoveredOverAbsoluteTimeChanged(unsigned int)),
+     this, TQ_SLOT (slotHoveredOverAbsoluteTimeChanged(unsigned int)));
 
     TQObject::connect
-    (doc, TQT_SIGNAL(pointerPositionChanged(timeT)),
-     TQT_TQOBJECT(this), TQT_SLOT(slotSetPointerPosition(timeT)));
+    (doc, TQ_SIGNAL(pointerPositionChanged(timeT)),
+     this, TQ_SLOT(slotSetPointerPosition(timeT)));
 
     MATRIX_DEBUG << "MatrixView : applying layout\n";
 
@@ -463,32 +463,32 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     TQObject::disconnect
     (topStandardRuler->getLoopRuler(),
-     TQT_SIGNAL(setPointerPosition(timeT)), 0, 0);
+     TQ_SIGNAL(setPointerPosition(timeT)), 0, 0);
 
     TQObject::connect
     (topStandardRuler->getLoopRuler(),
-     TQT_SIGNAL(setPointerPosition(timeT)),
-     TQT_TQOBJECT(this), TQT_SLOT(slotSetInsertCursorPosition(timeT)));
+     TQ_SIGNAL(setPointerPosition(timeT)),
+     this, TQ_SLOT(slotSetInsertCursorPosition(timeT)));
 
     TQObject::connect
     (topStandardRuler,
-     TQT_SIGNAL(dragPointerToPosition(timeT)),
-     TQT_TQOBJECT(this), TQT_SLOT(slotSetInsertCursorPosition(timeT)));
+     TQ_SIGNAL(dragPointerToPosition(timeT)),
+     this, TQ_SLOT(slotSetInsertCursorPosition(timeT)));
 
     topStandardRuler->getLoopRuler()->setBackgroundColor
     (GUIPalette::getColour(GUIPalette::InsertCursorRuler));
 
-    connect(topStandardRuler->getLoopRuler(), TQT_SIGNAL(startMouseMove(int)),
-            m_canvasView, TQT_SLOT(startAutoScroll(int)));
-    connect(topStandardRuler->getLoopRuler(), TQT_SIGNAL(stopMouseMove()),
-            m_canvasView, TQT_SLOT(stopAutoScroll()));
+    connect(topStandardRuler->getLoopRuler(), TQ_SIGNAL(startMouseMove(int)),
+            m_canvasView, TQ_SLOT(startAutoScroll(int)));
+    connect(topStandardRuler->getLoopRuler(), TQ_SIGNAL(stopMouseMove()),
+            m_canvasView, TQ_SLOT(stopAutoScroll()));
 
-    connect(bottomStandardRuler->getLoopRuler(), TQT_SIGNAL(startMouseMove(int)),
-            m_canvasView, TQT_SLOT(startAutoScroll(int)));
-    connect(bottomStandardRuler->getLoopRuler(), TQT_SIGNAL(stopMouseMove()),
-            m_canvasView, TQT_SLOT(stopAutoScroll()));
-    connect(m_bottomStandardRuler, TQT_SIGNAL(dragPointerToPosition(timeT)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotSetPointerPosition(timeT)));
+    connect(bottomStandardRuler->getLoopRuler(), TQ_SIGNAL(startMouseMove(int)),
+            m_canvasView, TQ_SLOT(startAutoScroll(int)));
+    connect(bottomStandardRuler->getLoopRuler(), TQ_SIGNAL(stopMouseMove()),
+            m_canvasView, TQ_SLOT(stopAutoScroll()));
+    connect(m_bottomStandardRuler, TQ_SIGNAL(dragPointerToPosition(timeT)),
+            this, TQ_SLOT(slotSetPointerPosition(timeT)));
 
     // Force height for the moment
     //
@@ -637,148 +637,148 @@ void MatrixView::setupActions()
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/select.xpm"));
 
     toolAction = new TDERadioAction(i18n("&Select and Edit"), icon, Key_F2,
-                                  TQT_TQOBJECT(this), TQT_SLOT(slotSelectSelected()),
+                                  this, TQ_SLOT(slotSelectSelected()),
                                   actionCollection(), "select");
     toolAction->setExclusiveGroup("tools");
 
     toolAction = new TDERadioAction(i18n("&Draw"), "pencil", Key_F3,
-                                  TQT_TQOBJECT(this), TQT_SLOT(slotPaintSelected()),
+                                  this, TQ_SLOT(slotPaintSelected()),
                                   actionCollection(), "draw");
     toolAction->setExclusiveGroup("tools");
 
     toolAction = new TDERadioAction(i18n("&Erase"), "eraser", Key_F4,
-                                  TQT_TQOBJECT(this), TQT_SLOT(slotEraseSelected()),
+                                  this, TQ_SLOT(slotEraseSelected()),
                                   actionCollection(), "erase");
     toolAction->setExclusiveGroup("tools");
 
     toolAction = new TDERadioAction(i18n("&Move"), "move", Key_F5,
-                                  TQT_TQOBJECT(this), TQT_SLOT(slotMoveSelected()),
+                                  this, TQ_SLOT(slotMoveSelected()),
                                   actionCollection(), "move");
     toolAction->setExclusiveGroup("tools");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/resize.xpm");
     icon = TQIconSet(pixmap);
     toolAction = new TDERadioAction(i18n("Resi&ze"), icon, Key_F6,
-                                  TQT_TQOBJECT(this), TQT_SLOT(slotResizeSelected()),
+                                  this, TQ_SLOT(slotResizeSelected()),
                                   actionCollection(), "resize");
     toolAction->setExclusiveGroup("tools");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap("chord")));
     (new TDEToggleAction(i18n("C&hord Insert Mode"), icon, Key_H,
-                       TQT_TQOBJECT(this), TQT_SLOT(slotUpdateInsertModeStatus()),
+                       this, TQ_SLOT(slotUpdateInsertModeStatus()),
                        actionCollection(), "chord_mode"))->
     setChecked(false);
 
     pixmap.load(pixmapDir + "/toolbar/step_by_step.xpm");
     icon = TQIconSet(pixmap);
-    new TDEToggleAction(i18n("Ste&p Recording"), icon, 0, TQT_TQOBJECT(this),
-                      TQT_SLOT(slotToggleStepByStep()), actionCollection(),
+    new TDEToggleAction(i18n("Ste&p Recording"), icon, 0, this,
+                      TQ_SLOT(slotToggleStepByStep()), actionCollection(),
                       "toggle_step_by_step");
 
     pixmap.load(pixmapDir + "/toolbar/quantize.png");
     icon = TQIconSet(pixmap);
-    new TDEAction(EventQuantizeCommand::getGlobalName(), icon, Key_Equal, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransformsQuantize()), actionCollection(),
+    new TDEAction(EventQuantizeCommand::getGlobalName(), icon, Key_Equal, this,
+                TQ_SLOT(slotTransformsQuantize()), actionCollection(),
                 "quantize");
 
-    new TDEAction(i18n("Repeat Last Quantize"), Key_Plus, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransformsRepeatQuantize()), actionCollection(),
+    new TDEAction(i18n("Repeat Last Quantize"), Key_Plus, this,
+                TQ_SLOT(slotTransformsRepeatQuantize()), actionCollection(),
                 "repeat_quantize");
 
-    new TDEAction(CollapseNotesCommand::getGlobalName(), Key_Equal + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransformsCollapseNotes()), actionCollection(),
+    new TDEAction(CollapseNotesCommand::getGlobalName(), Key_Equal + CTRL, this,
+                TQ_SLOT(slotTransformsCollapseNotes()), actionCollection(),
                 "collapse_notes");
 
-    new TDEAction(i18n("&Legato"), Key_Minus, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransformsLegato()), actionCollection(),
+    new TDEAction(i18n("&Legato"), Key_Minus, this,
+                TQ_SLOT(slotTransformsLegato()), actionCollection(),
                 "legatoize");
 
     new TDEAction(ChangeVelocityCommand::getGlobalName(10), 0,
-                Key_Up + SHIFT, TQT_TQOBJECT(this),
-                TQT_SLOT(slotVelocityUp()), actionCollection(),
+                Key_Up + SHIFT, this,
+                TQ_SLOT(slotVelocityUp()), actionCollection(),
                 "velocity_up");
 
     new TDEAction(ChangeVelocityCommand::getGlobalName( -10), 0,
-                Key_Down + SHIFT, TQT_TQOBJECT(this),
-                TQT_SLOT(slotVelocityDown()), actionCollection(),
+                Key_Down + SHIFT, this,
+                TQ_SLOT(slotVelocityDown()), actionCollection(),
                 "velocity_down");
 
-    new TDEAction(i18n("Set to Current Velocity"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSetVelocitiesToCurrent()), actionCollection(),
+    new TDEAction(i18n("Set to Current Velocity"), 0, this,
+                TQ_SLOT(slotSetVelocitiesToCurrent()), actionCollection(),
                 "set_to_current_velocity");
 
-    new TDEAction(i18n("Set Event &Velocities..."), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSetVelocities()), actionCollection(),
+    new TDEAction(i18n("Set Event &Velocities..."), 0, this,
+                TQ_SLOT(slotSetVelocities()), actionCollection(),
                 "set_velocities");
 
-    new TDEAction(i18n("Trigger Se&gment..."), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTriggerSegment()), actionCollection(),
+    new TDEAction(i18n("Trigger Se&gment..."), 0, this,
+                TQ_SLOT(slotTriggerSegment()), actionCollection(),
                 "trigger_segment");
 
-    new TDEAction(i18n("Remove Triggers..."), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRemoveTriggers()), actionCollection(),
+    new TDEAction(i18n("Remove Triggers..."), 0, this,
+                TQ_SLOT(slotRemoveTriggers()), actionCollection(),
                 "remove_trigger");
 
-    new TDEAction(i18n("Select &All"), Key_A + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSelectAll()), actionCollection(),
+    new TDEAction(i18n("Select &All"), Key_A + CTRL, this,
+                TQ_SLOT(slotSelectAll()), actionCollection(),
                 "select_all");
 
-    new TDEAction(i18n("&Delete"), Key_Delete, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditDelete()), actionCollection(),
+    new TDEAction(i18n("&Delete"), Key_Delete, this,
+                TQ_SLOT(slotEditDelete()), actionCollection(),
                 "delete");
 
-    new TDEAction(i18n("Cursor &Back"), 0, Key_Left, TQT_TQOBJECT(this),
-                TQT_SLOT(slotStepBackward()), actionCollection(),
+    new TDEAction(i18n("Cursor &Back"), 0, Key_Left, this,
+                TQ_SLOT(slotStepBackward()), actionCollection(),
                 "cursor_back");
 
-    new TDEAction(i18n("Cursor &Forward"), 0, Key_Right, TQT_TQOBJECT(this),
-                TQT_SLOT(slotStepForward()), actionCollection(),
+    new TDEAction(i18n("Cursor &Forward"), 0, Key_Right, this,
+                TQ_SLOT(slotStepForward()), actionCollection(),
                 "cursor_forward");
 
-    new TDEAction(i18n("Cursor Ba&ck Bar"), 0, Key_Left + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJumpBackward()), actionCollection(),
+    new TDEAction(i18n("Cursor Ba&ck Bar"), 0, Key_Left + CTRL, this,
+                TQ_SLOT(slotJumpBackward()), actionCollection(),
                 "cursor_back_bar");
 
-    new TDEAction(i18n("Cursor For&ward Bar"), 0, Key_Right + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJumpForward()), actionCollection(),
+    new TDEAction(i18n("Cursor For&ward Bar"), 0, Key_Right + CTRL, this,
+                TQ_SLOT(slotJumpForward()), actionCollection(),
                 "cursor_forward_bar");
 
-    new TDEAction(i18n("Cursor Back and Se&lect"), SHIFT + Key_Left, TQT_TQOBJECT(this),
-                TQT_SLOT(slotExtendSelectionBackward()), actionCollection(),
+    new TDEAction(i18n("Cursor Back and Se&lect"), SHIFT + Key_Left, this,
+                TQ_SLOT(slotExtendSelectionBackward()), actionCollection(),
                 "extend_selection_backward");
 
-    new TDEAction(i18n("Cursor Forward and &Select"), SHIFT + Key_Right, TQT_TQOBJECT(this),
-                TQT_SLOT(slotExtendSelectionForward()), actionCollection(),
+    new TDEAction(i18n("Cursor Forward and &Select"), SHIFT + Key_Right, this,
+                TQ_SLOT(slotExtendSelectionForward()), actionCollection(),
                 "extend_selection_forward");
 
-    new TDEAction(i18n("Cursor Back Bar and Select"), SHIFT + CTRL + Key_Left, TQT_TQOBJECT(this),
-                TQT_SLOT(slotExtendSelectionBackwardBar()), actionCollection(),
+    new TDEAction(i18n("Cursor Back Bar and Select"), SHIFT + CTRL + Key_Left, this,
+                TQ_SLOT(slotExtendSelectionBackwardBar()), actionCollection(),
                 "extend_selection_backward_bar");
 
-    new TDEAction(i18n("Cursor Forward Bar and Select"), SHIFT + CTRL + Key_Right, TQT_TQOBJECT(this),
-                TQT_SLOT(slotExtendSelectionForwardBar()), actionCollection(),
+    new TDEAction(i18n("Cursor Forward Bar and Select"), SHIFT + CTRL + Key_Right, this,
+                TQ_SLOT(slotExtendSelectionForwardBar()), actionCollection(),
                 "extend_selection_forward_bar");
 
     new TDEAction(i18n("Cursor to St&art"), 0,
                 /* #1025717: conflicting meanings for ctrl+a - dupe with Select All
-                  Key_A + CTRL, */ TQT_TQOBJECT(this), 
-                TQT_SLOT(slotJumpToStart()), actionCollection(),
+                  Key_A + CTRL, */ this, 
+                TQ_SLOT(slotJumpToStart()), actionCollection(),
                 "cursor_start");
 
-    new TDEAction(i18n("Cursor to &End"), 0, Key_E + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJumpToEnd()), actionCollection(),
+    new TDEAction(i18n("Cursor to &End"), 0, Key_E + CTRL, this,
+                TQ_SLOT(slotJumpToEnd()), actionCollection(),
                 "cursor_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-cursor-to-pointer")));
-    new TDEAction(i18n("Cursor to &Playback Pointer"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJumpCursorToPlayback()), actionCollection(),
+    new TDEAction(i18n("Cursor to &Playback Pointer"), icon, 0, this,
+                TQ_SLOT(slotJumpCursorToPlayback()), actionCollection(),
                 "cursor_to_playback_pointer");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-play")));
-    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
-                TQT_SIGNAL(play()), actionCollection(), "play");
+    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, this,
+                TQ_SIGNAL(play()), actionCollection(), "play");
     // Alternative shortcut for Play
     TDEShortcut playShortcut = play->shortcut();
     playShortcut.append( KKey(Key_Return + CTRL) );
@@ -786,71 +786,71 @@ void MatrixView::setupActions()
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-stop")));
-    new TDEAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
-                TQT_SIGNAL(stop()), actionCollection(), "stop");
+    new TDEAction(i18n("&Stop"), icon, Key_Insert, this,
+                TQ_SIGNAL(stop()), actionCollection(), "stop");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind")));
-    new TDEAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlayback()), actionCollection(),
+    new TDEAction(i18n("Re&wind"), icon, Key_End, this,
+                TQ_SIGNAL(rewindPlayback()), actionCollection(),
                 "playback_pointer_back_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd")));
-    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
+    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+                TQ_SIGNAL(fastForwardPlayback()), actionCollection(),
                 "playback_pointer_forward_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind-end")));
-    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
+    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, this,
+                TQ_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
                 "playback_pointer_start");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd-end")));
-    new TDEAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
+    new TDEAction(i18n("Fast Forward to &End"), icon, 0, this,
+                TQ_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
                 "playback_pointer_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-pointer-to-cursor")));
-    new TDEAction(i18n("Playback Pointer to &Cursor"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJumpPlaybackToCursor()), actionCollection(),
+    new TDEAction(i18n("Playback Pointer to &Cursor"), icon, 0, this,
+                TQ_SLOT(slotJumpPlaybackToCursor()), actionCollection(),
                 "playback_pointer_to_cursor");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-solo")));
-    new TDEToggleAction(i18n("&Solo"), icon, 0, TQT_TQOBJECT(this),
-                      TQT_SLOT(slotToggleSolo()), actionCollection(),
+    new TDEToggleAction(i18n("&Solo"), icon, 0, this,
+                      TQ_SLOT(slotToggleSolo()), actionCollection(),
                       "toggle_solo");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-tracking")));
-    (new TDEToggleAction(i18n("Scro&ll to Follow Playback"), icon, Key_Pause, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotToggleTracking()), actionCollection(),
+    (new TDEToggleAction(i18n("Scro&ll to Follow Playback"), icon, Key_Pause, this,
+                       TQ_SLOT(slotToggleTracking()), actionCollection(),
                        "toggle_tracking"))->setChecked(m_playTracking);
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-panic")));
-    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
-                TQT_SIGNAL(panic()), actionCollection(), "panic");
+    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+                TQ_SIGNAL(panic()), actionCollection(), "panic");
 
-    new TDEAction(i18n("Set Loop to Selection"), Key_Semicolon + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotPreviewSelection()), actionCollection(),
+    new TDEAction(i18n("Set Loop to Selection"), Key_Semicolon + CTRL, this,
+                TQ_SLOT(slotPreviewSelection()), actionCollection(),
                 "preview_selection");
 
-    new TDEAction(i18n("Clear L&oop"), Key_Colon + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotClearLoop()), actionCollection(),
+    new TDEAction(i18n("Clear L&oop"), Key_Colon + CTRL, this,
+                TQ_SLOT(slotClearLoop()), actionCollection(),
                 "clear_loop");
 
-    new TDEAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
-                TQT_SLOT(slotClearSelection()), actionCollection(),
+    new TDEAction(i18n("Clear Selection"), Key_Escape, this,
+                TQ_SLOT(slotClearSelection()), actionCollection(),
                 "clear_selection");
 
     //    icon = TQIconSet(TQCanvasPixmap(pixmapDir + "/toolbar/eventfilter.xpm"));
-    new TDEAction(i18n("&Filter Selection"), "filter", Key_F + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotFilterSelection()), actionCollection(),
+    new TDEAction(i18n("&Filter Selection"), "filter", Key_F + CTRL, this,
+                TQ_SLOT(slotFilterSelection()), actionCollection(),
                 "filter_selection");
 
     timeT crotchetDuration = Note(Note::Crotchet).getDuration();
@@ -874,17 +874,17 @@ void MatrixView::setupActions()
         timeT d = m_snapValues[i];
 
         if (d == SnapGrid::NoSnap) {
-            new TDEAction(i18n("&No Snap"), 0, TQT_TQOBJECT(this),
-                        TQT_SLOT(slotSetSnapFromAction()),
+            new TDEAction(i18n("&No Snap"), 0, this,
+                        TQ_SLOT(slotSetSnapFromAction()),
                         actionCollection(), "snap_none");
         } else if (d == SnapGrid::SnapToUnit) {
         } else if (d == SnapGrid::SnapToBeat) {
-            new TDEAction(i18n("Snap to Bea&t"), Key_1, TQT_TQOBJECT(this),
-                        TQT_SLOT(slotSetSnapFromAction()),
+            new TDEAction(i18n("Snap to Bea&t"), Key_1, this,
+                        TQ_SLOT(slotSetSnapFromAction()),
                         actionCollection(), "snap_beat");
         } else if (d == SnapGrid::SnapToBar) {
-            new TDEAction(i18n("Snap to &Bar"), Key_5, TQT_TQOBJECT(this),
-                        TQT_SLOT(slotSetSnapFromAction()),
+            new TDEAction(i18n("Snap to &Bar"), Key_5, this,
+                        TQ_SLOT(slotSetSnapFromAction()),
                         actionCollection(), "snap_bar");
         } else {
 
@@ -903,8 +903,8 @@ void MatrixView::setupActions()
 
             TQString actionName = TQString("snap_%1").arg(int((crotchetDuration * 4) / d));
             if (d == (crotchetDuration * 3) / 2) actionName = "snap_3";
-            new TDEAction(i18n("Snap to %1").arg(label), pixmap, cut, TQT_TQOBJECT(this),
-                        TQT_SLOT(slotSetSnapFromAction()), actionCollection(),
+            new TDEAction(i18n("Snap to %1").arg(label), pixmap, cut, this,
+                        TQ_SLOT(slotSetSnapFromAction()), actionCollection(),
                         actionName.ascii());
         }
     }
@@ -912,17 +912,17 @@ void MatrixView::setupActions()
     //
     // Settings menu
     //
-    new TDEAction(i18n("Show Instrument Parameters"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDockParametersBack()),
+    new TDEAction(i18n("Show Instrument Parameters"), 0, this,
+                TQ_SLOT(slotDockParametersBack()),
                 actionCollection(),
                 "show_inst_parameters");
 
-    new TDEToggleAction(i18n("Show Ch&ord Name Ruler"), 0, TQT_TQOBJECT(this),
-                      TQT_SLOT(slotToggleChordsRuler()),
+    new TDEToggleAction(i18n("Show Ch&ord Name Ruler"), 0, this,
+                      TQ_SLOT(slotToggleChordsRuler()),
                       actionCollection(), "show_chords_ruler");
 
-    new TDEToggleAction(i18n("Show &Tempo Ruler"), 0, TQT_TQOBJECT(this),
-                      TQT_SLOT(slotToggleTempoRuler()),
+    new TDEToggleAction(i18n("Show &Tempo Ruler"), 0, this,
+                      TQ_SLOT(slotToggleTempoRuler()),
                       actionCollection(), "show_tempo_ruler");
 
     createGUI(getRCFileName(), false);
@@ -1312,11 +1312,11 @@ void MatrixView::slotSelectSelected()
 {
     EditTool* selector = m_toolBox->getTool(MatrixSelector::ToolName);
 
-    connect(selector, TQT_SIGNAL(gotSelection()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotNewSelection()));
+    connect(selector, TQ_SIGNAL(gotSelection()),
+            this, TQ_SLOT(slotNewSelection()));
 
-    connect(selector, TQT_SIGNAL(editTriggerSegment(int)),
-            TQT_TQOBJECT(this), TQT_SIGNAL(editTriggerSegment(int)));
+    connect(selector, TQ_SIGNAL(editTriggerSegment(int)),
+            this, TQ_SIGNAL(editTriggerSegment(int)));
 
     setTool(selector);
 }
@@ -1396,7 +1396,7 @@ void MatrixView::slotMousePressed(timeT time, int pitch,
 
     m_tool->handleMousePress(time, pitch, 0, e, el);
 
-    if (e->button() != Qt::RightButton) {
+    if (e->button() != TQt::RightButton) {
         getCanvasView()->startAutoScroll();
     }
 
@@ -2147,8 +2147,8 @@ MatrixView::initActionsToolbar()
         }
     }
 
-    connect(m_snapGridCombo, TQT_SIGNAL(activated(int)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotSetSnapFromIndex(int)));
+    connect(m_snapGridCombo, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSetSnapFromIndex(int)));
 
     // Velocity combo.  Not a spin box, because the spin box is too
     // slow to use unless we make it typeable into, and then it takes
@@ -2181,8 +2181,8 @@ MatrixView::initActionsToolbar()
 
     m_quantizeCombo->insertItem(noMap, i18n("Off"));
 
-    connect(m_quantizeCombo, TQT_SIGNAL(activated(int)),
-            TQT_TQOBJECT(this), TQT_SLOT(slotQuantizeSelection(int)));
+    connect(m_quantizeCombo, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotQuantizeSelection(int)));
 }
 
 void
@@ -2215,7 +2215,7 @@ MatrixView::initZoomToolbar()
     }
 
     m_hZoomSlider = new ZoomSlider<double>
-                    (zoomSizes, -1, Qt::Horizontal, zoomToolbar, "tde toolbar widget");
+                    (zoomSizes, -1, TQt::Horizontal, zoomToolbar, "tde toolbar widget");
     m_hZoomSlider->setTracking(true);
     m_hZoomSlider->setFocusPolicy(TQWidget::NoFocus);
 
@@ -2224,8 +2224,8 @@ MatrixView::initZoomToolbar()
     m_zoomLabel->setFixedWidth(80);
 
     connect(m_hZoomSlider,
-            TQT_SIGNAL(valueChanged(int)),
-            TQT_SLOT(slotChangeHorizontalZoom(int)));
+            TQ_SIGNAL(valueChanged(int)),
+            TQ_SLOT(slotChangeHorizontalZoom(int)));
 
 }
 
@@ -2919,7 +2919,7 @@ MatrixView::slotToggleStepByStep()
         return ;
     }
     if (action->isChecked()) { // after toggling, that is
-        emit stepByStepTargetRequested(TQT_TQOBJECT(this));
+        emit stepByStepTargetRequested(this);
     } else {
         emit stepByStepTargetRequested(0);
     }
@@ -3023,20 +3023,20 @@ MatrixView::slotPercussionSetChanged(Instrument * newInstr)
 
 
     TQObject::connect
-    (pitchRuler, TQT_SIGNAL(hoveredOverKeyChanged(unsigned int)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
+    (pitchRuler, TQ_SIGNAL(hoveredOverKeyChanged(unsigned int)),
+     this, TQ_SLOT (slotHoveredOverKeyChanged(unsigned int)));
 
     TQObject::connect
-    (pitchRuler, TQT_SIGNAL(keyPressed(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeyPressed(unsigned int, bool)));
+    (pitchRuler, TQ_SIGNAL(keyPressed(unsigned int, bool)),
+     this, TQ_SLOT (slotKeyPressed(unsigned int, bool)));
 
     TQObject::connect
-    (pitchRuler, TQT_SIGNAL(keySelected(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeySelected(unsigned int, bool)));
+    (pitchRuler, TQ_SIGNAL(keySelected(unsigned int, bool)),
+     this, TQ_SLOT (slotKeySelected(unsigned int, bool)));
 
     TQObject::connect
-    (pitchRuler, TQT_SIGNAL(keyReleased(unsigned int, bool)),
-     TQT_TQOBJECT(this), TQT_SLOT (slotKeyReleased(unsigned int, bool)));
+    (pitchRuler, TQ_SIGNAL(keyReleased(unsigned int, bool)),
+     this, TQ_SLOT (slotKeyReleased(unsigned int, bool)));
 
     // Replace the old pitchruler widget
     m_pitchRuler = pitchRuler;
