@@ -100,11 +100,11 @@ public:
         m_barNumbersEvery = barNumbersEvery;
     }
 
-    LinedStaff::setPageMode;
-    LinedStaff::setPageWidth;
-    LinedStaff::setRowsPerPage;
-    LinedStaff::setRowSpacing;
-    LinedStaff::setConnectingLineLength;
+    using LinedStaff::setPageMode;
+    using LinedStaff::setPageWidth;
+    using LinedStaff::setRowsPerPage;
+    using LinedStaff::setRowSpacing;
+    using LinedStaff::setConnectingLineLength;
 
     /**
      * Gets a read-only reference to the pixmap factory used by the
