@@ -106,7 +106,7 @@ class NotationView : public EditView,
     friend class NotationSelectionPaster;
     friend class LilyPondExporter;
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
