@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -204,7 +202,7 @@ NoteFont::lookupDrawRep(TQPixmap *pixmap) const
             return 0;
 
         if (image.depth() > 1) {
-            image = image.convertDepth(1, Qt::MonoOnly | Qt::ThresholdDither);
+            image = image.convertDepth(1, TQt::MonoOnly | TQt::ThresholdDither);
         }
 
         NoteCharacterDrawRep *a = new NoteCharacterDrawRep();
