@@ -162,10 +162,10 @@ TrackEditor::init(TQWidget* rosegardenguiview)
                          m_doc->getStudio(),
                          m_rulerScale, getTrackCellHeight());
 
-    connect(rosegardenguiview, TQT_SIGNAL(instrumentParametersChanged(InstrumentId)),
-            m_compositionModel, TQT_SLOT(slotInstrumentParametersChanged(InstrumentId)));
-    connect(rosegardenguiview->parent(), TQT_SIGNAL(instrumentParametersChanged(InstrumentId)),
-            m_compositionModel, TQT_SLOT(slotInstrumentParametersChanged(InstrumentId)));
+    connect(rosegardenguiview, TQ_SIGNAL(instrumentParametersChanged(InstrumentId)),
+            m_compositionModel, TQ_SLOT(slotInstrumentParametersChanged(InstrumentId)));
+    connect(rosegardenguiview->parent(), TQ_SIGNAL(instrumentParametersChanged(InstrumentId)),
+            m_compositionModel, TQ_SLOT(slotInstrumentParametersChanged(InstrumentId)));
 
     m_segmentCanvas = new CompositionView(m_doc, m_compositionModel, this);
 
@@ -221,105 +221,105 @@ TrackEditor::init(TQWidget* rosegardenguiview)
     m_trackButtonScroll->setBottomMargin(m_bottomStandardRuler->height() +
                                          m_segmentCanvas->horizontalScrollBar()->height());
 
-    connect(m_trackButtons, TQT_SIGNAL(widthChanged()),
-            this, TQT_SLOT(slotTrackButtonsWidthChanged()));
+    connect(m_trackButtons, TQ_SIGNAL(widthChanged()),
+            this, TQ_SLOT(slotTrackButtonsWidthChanged()));
 
-    connect(m_trackButtons, TQT_SIGNAL(trackSelected(int)),
-            rosegardenguiview, TQT_SLOT(slotSelectTrackSegments(int)));
+    connect(m_trackButtons, TQ_SIGNAL(trackSelected(int)),
+            rosegardenguiview, TQ_SLOT(slotSelectTrackSegments(int)));
 
-    connect(m_trackButtons, TQT_SIGNAL(instrumentSelected(int)),
-            rosegardenguiview, TQT_SLOT(slotUpdateInstrumentParameterBox(int)));
+    connect(m_trackButtons, TQ_SIGNAL(instrumentSelected(int)),
+            rosegardenguiview, TQ_SLOT(slotUpdateInstrumentParameterBox(int)));
 
-    connect(this, TQT_SIGNAL(stateChange(TQString, bool)),
-            rosegardenguiview, TQT_SIGNAL(stateChange(TQString, bool)));
+    connect(this, TQ_SIGNAL(stateChange(TQString, bool)),
+            rosegardenguiview, TQ_SIGNAL(stateChange(TQString, bool)));
 
-    connect(m_trackButtons, TQT_SIGNAL(modified()),
-            m_doc, TQT_SLOT(slotDocumentModified()));
+    connect(m_trackButtons, TQ_SIGNAL(modified()),
+            m_doc, TQ_SLOT(slotDocumentModified()));
 
-    connect(m_trackButtons, TQT_SIGNAL(muteButton(TrackId, bool)),
-            rosegardenguiview, TQT_SLOT(slotSetMuteButton(TrackId, bool)));
+    connect(m_trackButtons, TQ_SIGNAL(muteButton(TrackId, bool)),
+            rosegardenguiview, TQ_SLOT(slotSetMuteButton(TrackId, bool)));
 
     // connect loop rulers' follow-scroll signals
-    connect(m_topStandardRuler->getLoopRuler(), TQT_SIGNAL(startMouseMove(int)),
-            m_segmentCanvas, TQT_SLOT(startAutoScroll(int)));
-    connect(m_topStandardRuler->getLoopRuler(), TQT_SIGNAL(stopMouseMove()),
-            m_segmentCanvas, TQT_SLOT(stopAutoScroll()));
-    connect(m_bottomStandardRuler->getLoopRuler(), TQT_SIGNAL(startMouseMove(int)),
-            m_segmentCanvas, TQT_SLOT(startAutoScroll(int)));
-    connect(m_bottomStandardRuler->getLoopRuler(), TQT_SIGNAL(stopMouseMove()),
-            m_segmentCanvas, TQT_SLOT(stopAutoScroll()));
+    connect(m_topStandardRuler->getLoopRuler(), TQ_SIGNAL(startMouseMove(int)),
+            m_segmentCanvas, TQ_SLOT(startAutoScroll(int)));
+    connect(m_topStandardRuler->getLoopRuler(), TQ_SIGNAL(stopMouseMove()),
+            m_segmentCanvas, TQ_SLOT(stopAutoScroll()));
+    connect(m_bottomStandardRuler->getLoopRuler(), TQ_SIGNAL(startMouseMove(int)),
+            m_segmentCanvas, TQ_SLOT(startAutoScroll(int)));
+    connect(m_bottomStandardRuler->getLoopRuler(), TQ_SIGNAL(stopMouseMove()),
+            m_segmentCanvas, TQ_SLOT(stopAutoScroll()));
 
-    connect(m_segmentCanvas, TQT_SIGNAL(contentsMoving(int, int)),
-            this, TQT_SLOT(slotCanvasScrolled(int, int)));
+    connect(m_segmentCanvas, TQ_SIGNAL(contentsMoving(int, int)),
+            this, TQ_SLOT(slotCanvasScrolled(int, int)));
 
     // Synchronize bar buttons' scrollview with segment canvas' scrollbar
     //
-    connect(m_segmentCanvas->verticalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SLOT(slotVerticalScrollTrackButtons(int)));
+    connect(m_segmentCanvas->verticalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotVerticalScrollTrackButtons(int)));
 
-    connect(m_segmentCanvas->verticalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            this, TQT_SLOT(slotVerticalScrollTrackButtons(int)));
+    connect(m_segmentCanvas->verticalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            this, TQ_SLOT(slotVerticalScrollTrackButtons(int)));
 
     // scrolling with mouse wheel
-    connect(m_trackButtonScroll, TQT_SIGNAL(gotWheelEvent(TQWheelEvent*)),
-            m_segmentCanvas, TQT_SLOT(slotExternalWheelEvent(TQWheelEvent*)));
+    connect(m_trackButtonScroll, TQ_SIGNAL(gotWheelEvent(TQWheelEvent*)),
+            m_segmentCanvas, TQ_SLOT(slotExternalWheelEvent(TQWheelEvent*)));
 
     // Connect horizontal scrollbar
     //
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            m_topStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            m_topStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            m_topStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            m_topStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
 
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            m_bottomStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            m_bottomStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            m_bottomStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            m_bottomStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
 
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            m_tempoRuler, TQT_SLOT(slotScrollHoriz(int)));
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            m_tempoRuler, TQT_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            m_tempoRuler, TQ_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            m_tempoRuler, TQ_SLOT(slotScrollHoriz(int)));
 
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-            m_chordNameRuler, TQT_SLOT(slotScrollHoriz(int)));
-    connect(m_segmentCanvas->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-            m_chordNameRuler, TQT_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+            m_chordNameRuler, TQ_SLOT(slotScrollHoriz(int)));
+    connect(m_segmentCanvas->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+            m_chordNameRuler, TQ_SLOT(slotScrollHoriz(int)));
 
-    connect(this, TQT_SIGNAL(needUpdate()), m_segmentCanvas, TQT_SLOT(slotUpdateSegmentsDrawBuffer()));
+    connect(this, TQ_SIGNAL(needUpdate()), m_segmentCanvas, TQ_SLOT(slotUpdateSegmentsDrawBuffer()));
 
     connect(m_segmentCanvas->getModel(),
-            TQT_SIGNAL(selectedSegments(const SegmentSelection &)),
+            TQ_SIGNAL(selectedSegments(const SegmentSelection &)),
             rosegardenguiview,
-            TQT_SLOT(slotSelectedSegments(const SegmentSelection &)));
+            TQ_SLOT(slotSelectedSegments(const SegmentSelection &)));
 
-    connect(m_segmentCanvas, TQT_SIGNAL(zoomIn()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotZoomIn()));
-    connect(m_segmentCanvas, TQT_SIGNAL(zoomOut()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotZoomOut()));
+    connect(m_segmentCanvas, TQ_SIGNAL(zoomIn()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotZoomIn()));
+    connect(m_segmentCanvas, TQ_SIGNAL(zoomOut()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotZoomOut()));
 
-    connect(getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-            this, TQT_SLOT(update()));
+    connect(getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+            this, TQ_SLOT(update()));
 
-    connect(m_doc, TQT_SIGNAL(pointerPositionChanged(timeT)),
-            this, TQT_SLOT(slotSetPointerPosition(timeT)));
+    connect(m_doc, TQ_SIGNAL(pointerPositionChanged(timeT)),
+            this, TQ_SLOT(slotSetPointerPosition(timeT)));
 
     //
     // pointer and loop drag signals from top and bottom bar buttons (loop rulers actually)
     //
-    connect(m_topStandardRuler, TQT_SIGNAL(dragPointerToPosition(timeT)),
-            this, TQT_SLOT(slotPointerDraggedToPosition(timeT)));
-    connect(m_bottomStandardRuler, TQT_SIGNAL(dragPointerToPosition(timeT)),
-            this, TQT_SLOT(slotPointerDraggedToPosition(timeT)));
+    connect(m_topStandardRuler, TQ_SIGNAL(dragPointerToPosition(timeT)),
+            this, TQ_SLOT(slotPointerDraggedToPosition(timeT)));
+    connect(m_bottomStandardRuler, TQ_SIGNAL(dragPointerToPosition(timeT)),
+            this, TQ_SLOT(slotPointerDraggedToPosition(timeT)));
 
-    connect(m_topStandardRuler, TQT_SIGNAL(dragLoopToPosition(timeT)),
-            this, TQT_SLOT(slotLoopDraggedToPosition(timeT)));
-    connect(m_bottomStandardRuler, TQT_SIGNAL(dragLoopToPosition(timeT)),
-            this, TQT_SLOT(slotLoopDraggedToPosition(timeT)));
+    connect(m_topStandardRuler, TQ_SIGNAL(dragLoopToPosition(timeT)),
+            this, TQ_SLOT(slotLoopDraggedToPosition(timeT)));
+    connect(m_bottomStandardRuler, TQ_SIGNAL(dragLoopToPosition(timeT)),
+            this, TQ_SLOT(slotLoopDraggedToPosition(timeT)));
 
-    connect(m_doc, TQT_SIGNAL(loopChanged(timeT,
+    connect(m_doc, TQ_SIGNAL(loopChanged(timeT,
                                       timeT)),
-            this, TQT_SLOT(slotSetLoop(timeT, timeT)));
+            this, TQ_SLOT(slotSetLoop(timeT, timeT)));
 }
 
 void TrackEditor::slotReadjustCanvasSize()
@@ -756,7 +756,7 @@ void TrackEditor::dropEvent(TQDropEvent* event)
             // WARNING
             //
             // DO NOT PERFORM ANY OPERATIONS AFTER THAT
-            // EMITTING THIS TQT_SIGNAL TRIGGERS THE LOADING OF A NEW DOCUMENT
+            // EMITTING THIS TQ_SIGNAL TRIGGERS THE LOADING OF A NEW DOCUMENT
             // AND AS A CONSEQUENCE THE DELETION OF THIS TrackEditor OBJECT
             //
         } else {
