@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -135,8 +133,8 @@ EditView::EditView(RosegardenGUIDoc *doc,
 {
     m_controlRulers->setHoverCloseButton(true);
     m_controlRulers->setHoverCloseButtonDelayed(false);
-    connect(m_controlRulers, TQT_SIGNAL(closeRequest(TQWidget*)),
-            this, TQT_SLOT(slotRemoveControlRuler(TQWidget*)));
+    connect(m_controlRulers, TQ_SIGNAL(closeRequest(TQWidget*)),
+            this, TQ_SLOT(slotRemoveControlRuler(TQWidget*)));
 
     (dynamic_cast<TQBoxLayout*>(m_bottomBox->layout()))->setDirection(TQBoxLayout::BottomToTop);
 
@@ -283,10 +281,10 @@ void EditView::setTopStandardRuler(StandardRuler* w, TQWidget *leftBox)
     m_grid->addLayout(gl, TOPBARBUTTONS_ROW, m_mainCol);
 
     if (m_canvasView) {
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-                m_topStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-                m_topStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+                m_topStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+                m_topStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
     }
 }
 
@@ -298,10 +296,10 @@ void EditView::setBottomStandardRuler(StandardRuler* w)
     //     m_bottomBox->insertWidget(0, w);
 
     if (m_canvasView) {
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-                m_bottomStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-                m_bottomStandardRuler, TQT_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+                m_bottomStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+                m_bottomStandardRuler, TQ_SLOT(slotScrollHoriz(int)));
     }
 }
 
@@ -345,10 +343,10 @@ void EditView::addRuler(TQWidget* w)
     m_rulerBox->addWidget(w);
 
     if (m_canvasView) {
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-                w, TQT_SLOT(slotScrollHoriz(int)));
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-                w, TQT_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+                w, TQ_SLOT(slotScrollHoriz(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+                w, TQ_SLOT(slotScrollHoriz(int)));
     }
 }
 
@@ -365,14 +363,14 @@ void EditView::addControlRuler(ControlRuler* ruler)
     m_controlRulers->showPage(ruler);
 
     if (m_canvasView) {
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)),
-                ruler->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)));
-        connect(m_canvasView->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
-                ruler->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)),
+                ruler->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)));
+        connect(m_canvasView->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)),
+                ruler->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)));
     }
 
-    connect(ruler, TQT_SIGNAL(stateChange(const TQString&, bool)),
-            this, TQT_SLOT(slotStateChanged(const TQString&, bool)));
+    connect(ruler, TQ_SIGNAL(stateChange(const TQString&, bool)),
+            this, TQ_SLOT(slotStateChanged(const TQString&, bool)));
 
     stateChanged("have_control_ruler", KXMLGUIClient::StateReverse);
 }
@@ -426,10 +424,10 @@ void EditView::setCanvasView(RosegardenCanvasView *canvasView)
     //     m_horizontalScrollBar->setSteps(m_canvasView->horizontalScrollBar()->lineStep(),
     //                                     m_canvasView->horizontalScrollBar()->pageStep());
 
-    //     connect(m_horizontalScrollBar, TQT_SIGNAL(valueChanged(int)),
-    //             m_canvasView->horizontalScrollBar(), TQT_SIGNAL(valueChanged(int)));
-    //     connect(m_horizontalScrollBar, TQT_SIGNAL(sliderMoved(int)),
-    //             m_canvasView->horizontalScrollBar(), TQT_SIGNAL(sliderMoved(int)));
+    //     connect(m_horizontalScrollBar, TQ_SIGNAL(valueChanged(int)),
+    //             m_canvasView->horizontalScrollBar(), TQ_SIGNAL(valueChanged(int)));
+    //     connect(m_horizontalScrollBar, TQ_SIGNAL(sliderMoved(int)),
+    //             m_canvasView->horizontalScrollBar(), TQ_SIGNAL(sliderMoved(int)));
 
 }
 
@@ -728,132 +726,132 @@ EditView::setupActions()
     TQIconSet icon = TQIconSet(pixmap);
     new TDEAction(AddTempoChangeCommand::getGlobalName(),
 		icon, 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotAddTempo()),
+		this, TQ_SLOT(slotAddTempo()),
 		actionCollection(), "add_tempo");
 
     pixmap.load(pixmapDir + "/toolbar/event-insert-timesig.png");
     icon = TQIconSet(pixmap);
     new TDEAction(AddTimeSignatureCommand::getGlobalName(),
 		icon, 0,
-		TQT_TQOBJECT(this), TQT_SLOT(slotAddTimeSignature()),
+		this, TQ_SLOT(slotAddTimeSignature()),
 		actionCollection(), "add_time_signature");
 
     //
     // Transforms
     //
-    new TDEAction(i18n("&Halve Durations"), Key_H + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotHalveDurations()), actionCollection(),
+    new TDEAction(i18n("&Halve Durations"), Key_H + CTRL, this,
+                TQ_SLOT(slotHalveDurations()), actionCollection(),
                 "halve_durations");
 
-    new TDEAction(i18n("&Double Durations"), Key_H + CTRL + SHIFT, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDoubleDurations()), actionCollection(),
+    new TDEAction(i18n("&Double Durations"), Key_H + CTRL + SHIFT, this,
+                TQ_SLOT(slotDoubleDurations()), actionCollection(),
                 "double_durations");
 
-    new TDEAction(RescaleCommand::getGlobalName(), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRescale()), actionCollection(),
+    new TDEAction(RescaleCommand::getGlobalName(), 0, this,
+                TQ_SLOT(slotRescale()), actionCollection(),
                 "rescale");
 
     new TDEAction(TransposeCommand::getGlobalName(1), 0,
-                Key_Up, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransposeUp()), actionCollection(),
+                Key_Up, this,
+                TQ_SLOT(slotTransposeUp()), actionCollection(),
                 "transpose_up");
 
     new TDEAction(TransposeCommand::getGlobalName(12), 0,
-                Key_Up + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransposeUpOctave()), actionCollection(),
+                Key_Up + CTRL, this,
+                TQ_SLOT(slotTransposeUpOctave()), actionCollection(),
                 "transpose_up_octave");
 
     new TDEAction(TransposeCommand::getGlobalName( -1), 0,
-                Key_Down, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransposeDown()), actionCollection(),
+                Key_Down, this,
+                TQ_SLOT(slotTransposeDown()), actionCollection(),
                 "transpose_down");
 
     new TDEAction(TransposeCommand::getGlobalName( -12), 0,
-                Key_Down + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTransposeDownOctave()), actionCollection(),
+                Key_Down + CTRL, this,
+                TQ_SLOT(slotTransposeDownOctave()), actionCollection(),
                 "transpose_down_octave");
 
-    new TDEAction(TransposeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotTranspose()), actionCollection(),
+    new TDEAction(TransposeCommand::getGlobalName(0), 0, this,
+                TQ_SLOT(slotTranspose()), actionCollection(),
                 "general_transpose");
 
-    new TDEAction(TransposeCommand::getDiatonicGlobalName(0,0), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDiatonicTranspose()), actionCollection(),
+    new TDEAction(TransposeCommand::getDiatonicGlobalName(0,0), 0, this,
+                TQ_SLOT(slotDiatonicTranspose()), actionCollection(),
                 "general_diatonic_transpose");
 
-    new TDEAction(InvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotInvert()), actionCollection(),
+    new TDEAction(InvertCommand::getGlobalName(0), 0, this,
+                TQ_SLOT(slotInvert()), actionCollection(),
                 "invert");
 
-    new TDEAction(RetrogradeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRetrograde()), actionCollection(),
+    new TDEAction(RetrogradeCommand::getGlobalName(0), 0, this,
+                TQ_SLOT(slotRetrograde()), actionCollection(),
                 "retrograde");
 
-    new TDEAction(RetrogradeInvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotRetrogradeInvert()), actionCollection(),
+    new TDEAction(RetrogradeInvertCommand::getGlobalName(0), 0, this,
+                TQ_SLOT(slotRetrogradeInvert()), actionCollection(),
                 "retrograde_invert");
 
-    new TDEAction(i18n("Jog &Left"), Key_Left + ALT, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJogLeft()), actionCollection(),
+    new TDEAction(i18n("Jog &Left"), Key_Left + ALT, this,
+                TQ_SLOT(slotJogLeft()), actionCollection(),
                 "jog_left");
 
-    new TDEAction(i18n("Jog &Right"), Key_Right + ALT, TQT_TQOBJECT(this),
-                TQT_SLOT(slotJogRight()), actionCollection(),
+    new TDEAction(i18n("Jog &Right"), Key_Right + ALT, this,
+                TQ_SLOT(slotJogRight()), actionCollection(),
                 "jog_right");
 
     // Control rulers
     //
-    new TDEAction(i18n("Show Velocity Property Ruler"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotShowVelocityControlRuler()), actionCollection(),
+    new TDEAction(i18n("Show Velocity Property Ruler"), 0, this,
+                TQ_SLOT(slotShowVelocityControlRuler()), actionCollection(),
                 "show_velocity_control_ruler");
 
     /*
     new TDEAction(i18n("Show Controllers Events Ruler"), 0, this,
-                TQT_SLOT(slotShowControllerEventsRuler()), actionCollection(),
+                TQ_SLOT(slotShowControllerEventsRuler()), actionCollection(),
                 "show_controller_events_ruler");
                 */
 
     // Disabled for now
     //
     //     new TDEAction(i18n("Add Control Ruler..."), 0, this,
-    //                 TQT_SLOT(slotShowPropertyControlRuler()), actionCollection(),
+    //                 TQ_SLOT(slotShowPropertyControlRuler()), actionCollection(),
     //                 "add_control_ruler");
 
     //
     // Control Ruler context menu
     //
-    new TDEAction(i18n("Insert item"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotInsertControlRulerItem()), actionCollection(),
+    new TDEAction(i18n("Insert item"), 0, this,
+                TQ_SLOT(slotInsertControlRulerItem()), actionCollection(),
                 "insert_control_ruler_item");
 
     // This was on Key_Delete, but that conflicts with existing Delete commands
     // on individual edit views
-    new TDEAction(i18n("Erase selected items"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEraseControlRulerItem()), actionCollection(),
+    new TDEAction(i18n("Erase selected items"), 0, this,
+                TQ_SLOT(slotEraseControlRulerItem()), actionCollection(),
                 "erase_control_ruler_item");
 
-    new TDEAction(i18n("Clear ruler"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotClearControlRulerItem()), actionCollection(),
+    new TDEAction(i18n("Clear ruler"), 0, this,
+                TQ_SLOT(slotClearControlRulerItem()), actionCollection(),
                 "clear_control_ruler_item");
 
-    new TDEAction(i18n("Insert line of controllers"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotStartControlLineItem()), actionCollection(),
+    new TDEAction(i18n("Insert line of controllers"), 0, this,
+                TQ_SLOT(slotStartControlLineItem()), actionCollection(),
                 "start_control_line_item");
 
-    new TDEAction(i18n("Flip forward"), Key_BracketRight, TQT_TQOBJECT(this),
-                TQT_SLOT(slotFlipForwards()), actionCollection(),
+    new TDEAction(i18n("Flip forward"), Key_BracketRight, this,
+                TQ_SLOT(slotFlipForwards()), actionCollection(),
                 "flip_control_events_forward");
 
-    new TDEAction(i18n("Flip backwards"), Key_BracketLeft, TQT_TQOBJECT(this),
-                TQT_SLOT(slotFlipBackwards()), actionCollection(),
+    new TDEAction(i18n("Flip backwards"), Key_BracketLeft, this,
+                TQ_SLOT(slotFlipBackwards()), actionCollection(),
                 "flip_control_events_back");
 
-    new TDEAction(i18n("Draw property line"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotDrawPropertyLine()), actionCollection(),
+    new TDEAction(i18n("Draw property line"), 0, this,
+                TQ_SLOT(slotDrawPropertyLine()), actionCollection(),
                 "draw_property_line");
 
-    new TDEAction(i18n("Select all property values"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSelectAllProperties()), actionCollection(),
+    new TDEAction(i18n("Select all property values"), 0, this,
+                TQ_SLOT(slotSelectAllProperties()), actionCollection(),
                 "select_all_properties");
 }
 
@@ -903,8 +901,8 @@ EditView::setupAddControlRulerMenu()
             addControlRulerMenu->insertItem(itemStr, i++);
         }
 
-        connect(addControlRulerMenu, TQT_SIGNAL(activated(int)),
-                TQT_SLOT(slotAddControlRuler(int)));
+        connect(addControlRulerMenu, TQ_SIGNAL(activated(int)),
+                TQ_SLOT(slotAddControlRuler(int)));
     }
 
 }
@@ -1082,18 +1080,18 @@ EditView::createInsertPitchActionMenu()
                                     };
 
     TDEActionMenu *insertPitchActionMenu =
-        new TDEActionMenu(i18n("&Insert Note"), TQT_TQOBJECT(this), "insert_note_actionmenu");
+        new TDEActionMenu(i18n("&Insert Note"), this, "insert_note_actionmenu");
 
     for (int octave = 0; octave <= 2; ++octave) {
 
         TDEActionMenu *menu = insertPitchActionMenu;
         if (octave == 1) {
-            menu = new TDEActionMenu(i18n("&Upper Octave"), TQT_TQOBJECT(this),
+            menu = new TDEActionMenu(i18n("&Upper Octave"), this,
                                    "insert_note_actionmenu_upper_octave");
-            insertPitchActionMenu->insert(new TDEActionSeparator(TQT_TQOBJECT(this)));
+            insertPitchActionMenu->insert(new TDEActionSeparator(this));
             insertPitchActionMenu->insert(menu);
         } else if (octave == 2) {
-            menu = new TDEActionMenu(i18n("&Lower Octave"), TQT_TQOBJECT(this),
+            menu = new TDEActionMenu(i18n("&Lower Octave"), this,
                                    "insert_note_actionmenu_lower_octave");
             insertPitchActionMenu->insert(menu);
         }
@@ -1116,7 +1114,7 @@ EditView::createInsertPitchActionMenu()
                     new TDEAction
                     (flat.arg(notePitchNames[i]),
                      CTRL + SHIFT + notePitchKeys[octave][i],
-                     TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
+                     this, TQ_SLOT(slotInsertNoteFromAction()), actionCollection(),
                      TQString("insert_%1_flat%2").arg(i).arg(octaveSuffix).ascii());
 
                 menu->insert(insertPitchAction);
@@ -1126,7 +1124,7 @@ EditView::createInsertPitchActionMenu()
                 new TDEAction
                 (notePitchNames[i],
                  notePitchKeys[octave][i],
-                 TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
+                 this, TQ_SLOT(slotInsertNoteFromAction()), actionCollection(),
                  TQString("insert_%1%2").arg(i).arg(octaveSuffix).ascii());
 
             menu->insert(insertPitchAction);
@@ -1139,14 +1137,14 @@ EditView::createInsertPitchActionMenu()
                     new TDEAction
                     (sharp.arg(notePitchNames[i]),
                      SHIFT + notePitchKeys[octave][i],
-                     TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
+                     this, TQ_SLOT(slotInsertNoteFromAction()), actionCollection(),
                      TQString("insert_%1_sharp%2").arg(i).arg(octaveSuffix).ascii());
 
                 menu->insert(insertPitchAction);
             }
 
             if (i < 6)
-                menu->insert(new TDEActionSeparator(TQT_TQOBJECT(this)));
+                menu->insert(new TDEActionSeparator(this));
         }
     }
 
@@ -1220,12 +1218,12 @@ void EditView::slotAddTempo()
     TempoDialog tempoDlg(this, getDocument());
 
     connect(&tempoDlg,
-            TQT_SIGNAL(changeTempo(timeT,
+            TQ_SIGNAL(changeTempo(timeT,
                                tempoT,
                                tempoT,
                                TempoDialog::TempoDialogAction)),
             this,
-            TQT_SIGNAL(changeTempo(timeT,
+            TQ_SIGNAL(changeTempo(timeT,
                                tempoT,
                                tempoT,
                                TempoDialog::TempoDialogAction)));
@@ -1674,7 +1672,7 @@ ControlRuler* EditView::findRuler(const ControlParameter& controller, int &index
 
 PropertyControlRuler* EditView::makePropertyControlRuler(PropertyName propertyName)
 {
-    TQCanvas* controlRulerCanvas = new TQCanvas(TQT_TQOBJECT(this));
+    TQCanvas* controlRulerCanvas = new TQCanvas(this);
     TQSize viewSize = getViewSize();
     controlRulerCanvas->resize(viewSize.width(), ControlRuler::DefaultRulerHeight); // TODO - keep it in sync with main canvas size
 
@@ -1692,7 +1690,7 @@ PropertyControlRuler* EditView::makePropertyControlRuler(PropertyName propertyNa
 
 ControllerEventsRuler* EditView::makeControllerEventRuler(const ControlParameter *controller)
 {
-    TQCanvas* controlRulerCanvas = new TQCanvas(TQT_TQOBJECT(this));
+    TQCanvas* controlRulerCanvas = new TQCanvas(this);
     TQSize viewSize = getViewSize();
     controlRulerCanvas->resize(viewSize.width(), ControlRuler::DefaultRulerHeight); // TODO - keep it in sync with main canvas size
 //     TQCanvas* controlRulerCanvas = ControlRulerCanvasRepository::getCanvas(getCurrentSegment(), controller,
