@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -120,12 +118,12 @@ EditViewBase::EditViewBase(RosegardenGUIDoc *doc,
     m_doc->attachEditView(this);
 
     TQObject::connect
-    (getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-     this, TQT_SLOT(update()));
+    (getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+     this, TQ_SLOT(update()));
 
     TQObject::connect
-    (getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-     this, TQT_SLOT(slotTestClipboard()));
+    (getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+     this, TQ_SLOT(slotTestClipboard()));
 
     // create accelerators
     //
@@ -158,33 +156,33 @@ void EditViewBase::setupActions(TQString rcFileName, bool haveClipboard)
 
     // Actions all edit views will have
 
-    KStdAction::showToolbar(TQT_TQOBJECT(this), TQT_SLOT(slotToggleToolBar()),
+    KStdAction::showToolbar(this, TQ_SLOT(slotToggleToolBar()),
                             actionCollection(), "options_show_toolbar");
 
-    KStdAction::showStatusbar(TQT_TQOBJECT(this), TQT_SLOT(slotToggleStatusBar()),
+    KStdAction::showStatusbar(this, TQ_SLOT(slotToggleStatusBar()),
                               actionCollection(), "options_show_statusbar");
 
-    KStdAction::preferences(TQT_TQOBJECT(this),
-                            TQT_SLOT(slotConfigure()),
+    KStdAction::preferences(this,
+                            TQ_SLOT(slotConfigure()),
                             actionCollection());
 
-    KStdAction::keyBindings(TQT_TQOBJECT(this),
-                            TQT_SLOT(slotEditKeys()),
+    KStdAction::keyBindings(this,
+                            TQ_SLOT(slotEditKeys()),
                             actionCollection());
 
-    KStdAction::configureToolbars(TQT_TQOBJECT(this),
-                                  TQT_SLOT(slotEditToolbars()),
+    KStdAction::configureToolbars(this,
+                                  TQ_SLOT(slotEditToolbars()),
                                   actionCollection());
 
 
     // File menu
-    KStdAction::save (TQT_TQOBJECT(this), TQT_SIGNAL(saveFile()), actionCollection());
-    KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(slotCloseWindow()), actionCollection());
+    KStdAction::save (this, TQ_SIGNAL(saveFile()), actionCollection());
+    KStdAction::close(this, TQ_SLOT(slotCloseWindow()), actionCollection());
 
     if (haveClipboard) {
-        KStdAction::cut (TQT_TQOBJECT(this), TQT_SLOT(slotEditCut()), actionCollection());
-        KStdAction::copy (TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), actionCollection());
-        KStdAction::paste (TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
+        KStdAction::cut (this, TQ_SLOT(slotEditCut()), actionCollection());
+        KStdAction::copy (this, TQ_SLOT(slotEditCopy()), actionCollection());
+        KStdAction::paste (this, TQ_SLOT(slotEditPaste()), actionCollection());
     }
 
     new TDEToolBarPopupAction(i18n("Und&o"),
@@ -203,34 +201,34 @@ void EditViewBase::setupActions(TQString rcFileName, bool haveClipboard)
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/matrix.png");
     TQIconSet icon = TQIconSet(pixmap);
-    new TDEAction(i18n("Open in Matri&x Editor"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotOpenInMatrix()), actionCollection(),
+    new TDEAction(i18n("Open in Matri&x Editor"), icon, 0, this,
+                TQ_SLOT(slotOpenInMatrix()), actionCollection(),
                 "open_in_matrix");
 
     pixmap.load(pixmapDir + "/toolbar/matrix-percussion.png");
     icon = TQIconSet(pixmap);
-    new TDEAction(i18n("Open in &Percussion Matrix Editor"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotOpenInPercussionMatrix()), actionCollection(),
+    new TDEAction(i18n("Open in &Percussion Matrix Editor"), icon, 0, this,
+                TQ_SLOT(slotOpenInPercussionMatrix()), actionCollection(),
                 "open_in_percussion_matrix");
 
     pixmap.load(pixmapDir + "/toolbar/notation.png");
     icon = TQIconSet(pixmap);
-    new TDEAction(i18n("Open in &Notation Editor"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotOpenInNotation()), actionCollection(),
+    new TDEAction(i18n("Open in &Notation Editor"), icon, 0, this,
+                TQ_SLOT(slotOpenInNotation()), actionCollection(),
                 "open_in_notation");
 
     pixmap.load(pixmapDir + "/toolbar/eventlist.png");
     icon = TQIconSet(pixmap);
-    new TDEAction(i18n("Open in &Event List Editor"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotOpenInEventList()), actionCollection(),
+    new TDEAction(i18n("Open in &Event List Editor"), icon, 0, this,
+                TQ_SLOT(slotOpenInEventList()), actionCollection(),
                 "open_in_event_list");
 
-    new TDEAction(i18n("Set Segment Start Time..."), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSetSegmentStartTime()), actionCollection(),
+    new TDEAction(i18n("Set Segment Start Time..."), 0, this,
+                TQ_SLOT(slotSetSegmentStartTime()), actionCollection(),
                 "set_segment_start");
 
-    new TDEAction(i18n("Set Segment Duration..."), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSetSegmentDuration()), actionCollection(),
+    new TDEAction(i18n("Set Segment Duration..."), 0, this,
+                TQ_SLOT(slotSetSegmentDuration()), actionCollection(),
                 "set_segment_duration");
 
     // add undo and redo to edit menu and toolbar
@@ -256,8 +254,8 @@ void EditViewBase::slotEditToolbars()
 {
     KEditToolbar dlg(actionCollection(), getRCFileName());
 
-    connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
-            TQT_SLOT(slotUpdateToolbars()));
+    connect(&dlg, TQ_SIGNAL(newToolbarConfig()),
+            TQ_SLOT(slotUpdateToolbars()));
 
     dlg.exec();
 }
