@@ -113,10 +113,10 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
     layout->addWidget(m_closeButton);
     layout->addSpacing(5);
 
-    connect(m_applyButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotApply()));
-    connect(m_resetButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotReset()));
+    connect(m_applyButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotApply()));
+    connect(m_resetButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotReset()));
 
     //
     // Left-side list view
@@ -191,8 +191,8 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
         (m_pastePrograms,
                 i18n("Paste Program names from clipboard to current Bank"));
 
-    connect(m_listView, TQT_SIGNAL(currentChanged(TQListViewItem*)),
-            this, TQT_SLOT(slotPopulateDevice(TQListViewItem*)));
+    connect(m_listView, TQ_SIGNAL(currentChanged(TQListViewItem*)),
+            this, TQ_SLOT(slotPopulateDevice(TQListViewItem*)));
 
     TQFrame *vbox = new TQFrame(splitter);
     TQVBoxLayout *vboxLayout = new TQVBoxLayout(vbox, 8, 6);
@@ -217,44 +217,44 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
     m_variationCombo->insertItem(i18n("MSB"));
 
     // device/bank modification
-    connect(m_listView, TQT_SIGNAL(itemRenamed (TQListViewItem*, const TQString&, int)),
-            this, TQT_SLOT(slotModifyDeviceOrBankName(TQListViewItem*, const TQString&, int)));
+    connect(m_listView, TQ_SIGNAL(itemRenamed (TQListViewItem*, const TQString&, int)),
+            this, TQ_SLOT(slotModifyDeviceOrBankName(TQListViewItem*, const TQString&, int)));
 
-    connect(m_addBank, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotAddBank()));
+    connect(m_addBank, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotAddBank()));
 
-    connect(m_addKeyMapping, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotAddKeyMapping()));
+    connect(m_addKeyMapping, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotAddKeyMapping()));
 
-    connect(m_delete, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotDelete()));
+    connect(m_delete, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotDelete()));
 
-    connect(m_deleteAll, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotDeleteAll()));
+    connect(m_deleteAll, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotDeleteAll()));
 
-    connect(m_importBanks, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotImport()));
+    connect(m_importBanks, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotImport()));
 
-    connect(m_exportBanks, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotExport()));
+    connect(m_exportBanks, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotExport()));
 
-    connect(m_copyPrograms, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotEditCopy()));
+    connect(m_copyPrograms, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotEditCopy()));
 
-    connect(m_pastePrograms, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotEditPaste()));
+    connect(m_pastePrograms, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotEditPaste()));
 
-    connect(m_variationToggle, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotVariationToggled()));
+    connect(m_variationToggle, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotVariationToggled()));
 
-    connect(m_variationCombo, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotVariationChanged(int)));
+    connect(m_variationCombo, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotVariationChanged(int)));
 
     setupActions();
 
     m_doc->getCommandHistory()->attachView(actionCollection());
-    connect(m_doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-            this, TQT_SLOT(slotUpdate()));
+    connect(m_doc->getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+            this, TQ_SLOT(slotUpdate()));
 
     // Initialise the dialog
     //
@@ -301,14 +301,14 @@ BankEditorDialog::~BankEditorDialog()
 void
 BankEditorDialog::setupActions()
 {
-    TDEAction* close = KStdAction::close (TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()), actionCollection());
+    TDEAction* close = KStdAction::close (this, TQ_SLOT(slotFileClose()), actionCollection());
 
     m_closeButton->setText(close->text());
-    connect(m_closeButton, TQT_SIGNAL(clicked()),
-            TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()));
+    connect(m_closeButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotFileClose()));
 
-    KStdAction::copy (TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), actionCollection());
-    KStdAction::paste (TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
+    KStdAction::copy (this, TQ_SLOT(slotEditCopy()), actionCollection());
+    KStdAction::paste (this, TQ_SLOT(slotEditPaste()), actionCollection());
 
     // some adjustments
 
