@@ -93,7 +93,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
 
         setCaption(i18n("Manage MIDI Devices"));
 
-        TQGroupBox *groupBox = new TQGroupBox(2, Qt::Horizontal, i18n("Play devices"), mainBox);
+        TQGroupBox *groupBox = new TQGroupBox(2, TQt::Horizontal, i18n("Play devices"), mainBox);
 
         m_playTable = new TQTable(0, 2, groupBox);
         m_playTable->setSorting(false);
@@ -109,7 +109,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
 
         TQFrame *frame = new TQFrame(groupBox);
         TQVBoxLayout *vlayout = new TQVBoxLayout(frame);
-        TQGrid *buttons = new TQGrid(2, Qt::Horizontal, frame);
+        TQGrid *buttons = new TQGrid(2, TQt::Horizontal, frame);
         TQPushButton *addButton = new TQPushButton(i18n("New"), buttons);
         m_deletePlayButton = new TQPushButton(i18n("Delete"), buttons);
         m_importButton = new TQPushButton(i18n("Import..."), buttons);
@@ -138,20 +138,20 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
             (m_controllersButton,
                     i18n("View and edit Control Events for the selected device - these are special Event types that you can define against your device and control through Control Rulers or the Instrument Parameter Box "));
 
-        connect(addButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAddPlayDevice()));
-        connect(m_deletePlayButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDeletePlayDevice()));
-        connect(m_importButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotImport()));
-        connect(m_exportButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotExport()));
-        connect(m_banksButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSetBanks()));
-        connect(m_controllersButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSetControllers()));
+        connect(addButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddPlayDevice()));
+        connect(m_deletePlayButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDeletePlayDevice()));
+        connect(m_importButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotImport()));
+        connect(m_exportButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotExport()));
+        connect(m_banksButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSetBanks()));
+        connect(m_controllersButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSetControllers()));
 
-        connect(m_playTable, TQT_SIGNAL(valueChanged(int, int)),
-                this, TQT_SLOT(slotPlayValueChanged (int, int)));
-        connect(m_playTable, TQT_SIGNAL(currentChanged(int, int)),
-                this, TQT_SLOT(slotPlayDeviceSelected (int, int)));
+        connect(m_playTable, TQ_SIGNAL(valueChanged(int, int)),
+                this, TQ_SLOT(slotPlayValueChanged (int, int)));
+        connect(m_playTable, TQ_SIGNAL(currentChanged(int, int)),
+                this, TQ_SLOT(slotPlayDeviceSelected (int, int)));
 
         mainLayout->addWidget(groupBox);
-        groupBox = new TQGroupBox(2, Qt::Horizontal, i18n("Record devices"), mainBox);
+        groupBox = new TQGroupBox(2, TQt::Horizontal, i18n("Record devices"), mainBox);
 
         m_recordTable = new TQTable(0, 3, groupBox);
         m_recordTable->setSorting(false);
@@ -168,7 +168,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
 
         frame = new TQFrame(groupBox);
         vlayout = new TQVBoxLayout(frame);
-        buttons = new TQGrid(2, Qt::Horizontal, frame);
+        buttons = new TQGrid(2, TQt::Horizontal, frame);
         addButton = new TQPushButton(i18n("New"), buttons);
         m_deleteRecordButton = new TQPushButton(i18n("Delete"), buttons);
         vlayout->addWidget(buttons);
@@ -181,15 +181,15 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
             (m_deleteRecordButton,
                     i18n("Delete the selected device"));
 
-        connect(addButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAddRecordDevice()));
-        connect(m_deleteRecordButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDeleteRecordDevice()));
+        connect(addButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddRecordDevice()));
+        connect(m_deleteRecordButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDeleteRecordDevice()));
 
-        connect(m_recordTable, TQT_SIGNAL(currentChanged(int, int)),
-                this, TQT_SLOT(slotRecordDeviceSelected (int, int)));
-        connect(m_recordTable, TQT_SIGNAL(valueChanged(int, int)),
-                this, TQT_SLOT(slotRecordValueChanged (int, int)));
+        connect(m_recordTable, TQ_SIGNAL(currentChanged(int, int)),
+                this, TQ_SLOT(slotRecordDeviceSelected (int, int)));
+        connect(m_recordTable, TQ_SIGNAL(valueChanged(int, int)),
+                this, TQ_SLOT(slotRecordValueChanged (int, int)));
 
-        connect(document, TQT_SIGNAL(devicesResyncd()), this, TQT_SLOT(slotDevicesResyncd()));
+        connect(document, TQ_SIGNAL(devicesResyncd()), this, TQ_SLOT(slotDevicesResyncd()));
 
         m_noConnectionString = i18n("No connection");
 
@@ -212,12 +212,12 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
         layout->addWidget(closeButton);
         layout->addSpacing(5);
 
-        TDEAction* close = KStdAction::close(TQT_TQOBJECT(this),
-                                           TQT_SLOT(slotClose()),
+        TDEAction* close = KStdAction::close(this,
+                                           TQ_SLOT(slotClose()),
                                            actionCollection());
 
         closeButton->setText(close->text());
-        connect(closeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotClose()));
+        connect(closeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClose()));
 
         mainLayout->addWidget(btnBox);
 
@@ -237,8 +237,8 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
         createGUI("devicemanager.rc");
 
         m_document->getCommandHistory()->attachView(actionCollection());
-        connect(m_document->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-                this, TQT_SLOT(populate()));
+        connect(m_document->getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+                this, TQ_SLOT(populate()));
 
         m_playTable->setCurrentCell( -1, 0);
         m_recordTable->setCurrentCell( -1, 0);
