@@ -91,8 +91,8 @@ MidiProgramsEditor::makeAdditionalWidget(TQWidget *parent)
     gridLayout->addWidget(new TQLabel(i18n("Percussion"), frame),
                           0, 0, AlignLeft);
     gridLayout->addWidget(m_percussion, 0, 1, AlignLeft);
-    connect(m_percussion, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotNewPercussion()));
+    connect(m_percussion, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotNewPercussion()));
 
     gridLayout->addWidget(new TQLabel(i18n("MSB Value"), frame),
                           1, 0, AlignLeft);
@@ -108,8 +108,8 @@ MidiProgramsEditor::makeAdditionalWidget(TQWidget *parent)
         (m_lsb,
                 i18n("Selects a LSB controller Bank number (MSB/LSB pairs are always unique for any Device)"));
 
-    connect(m_msb, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SLOT(slotNewMSB(int)));
+    connect(m_msb, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotNewMSB(int)));
 
     gridLayout->addWidget(new TQLabel(i18n("LSB Value"), frame),
                           2, 0, AlignLeft);
@@ -117,8 +117,8 @@ MidiProgramsEditor::makeAdditionalWidget(TQWidget *parent)
     m_lsb->setMaxValue(127);
     gridLayout->addWidget(m_lsb, 2, 1, AlignLeft);
 
-    connect(m_lsb, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SLOT(slotNewLSB(int)));
+    connect(m_lsb, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotNewLSB(int)));
 
     return frame;
 }
@@ -389,7 +389,7 @@ MidiProgramsEditor::slotNameChanged(const TQString& programName)
         return ;
     }
 
-    TQString senderName = TQT_TQOBJECT_CONST(sender())->name();
+    TQString senderName = sender()->name();
 
     // Adjust value back to zero rated
     //
@@ -442,7 +442,7 @@ MidiProgramsEditor::slotNameChanged(const TQString& programName)
 void
 MidiProgramsEditor::slotEntryButtonPressed()
 {
-    TQPushButton* button = dynamic_cast<TQPushButton*>(TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
+    TQPushButton* button = dynamic_cast<TQPushButton*>(const_cast<TQObject*>(sender()));
     if (!button) {
         RG_DEBUG << "MidiProgramsEditor::slotEntryButtonPressed() : %%% ERROR - signal sender is not a TQPushButton\n";
         return ;
@@ -472,12 +472,12 @@ MidiProgramsEditor::slotEntryButtonPressed()
     int currentEntry = 0;
 
     menu->insertItem(i18n("<no key mapping>"), this,
-                     TQT_SLOT(slotEntryMenuItemSelected(int)), 0, 0);
+                     TQ_SLOT(slotEntryMenuItemSelected(int)), 0, 0);
     menu->setItemParameter(0, 0);
 
     for (int i = 0; i < kml.size(); ++i) {
         menu->insertItem(strtoqstr(kml[i].getName()),
-                         this, TQT_SLOT(slotEntryMenuItemSelected(int)),
+                         this, TQ_SLOT(slotEntryMenuItemSelected(int)),
                          0, i + 1);
         menu->setItemParameter(i + 1, i + 1);
         if (currentMapping && (kml[i] == *currentMapping))
