@@ -36,7 +36,7 @@ TimerCallbackAssistant::TimerCallbackAssistant(int ms, void (*callback)(void *da
         m_data(data)
 {
     TQTimer *timer = new TQTimer(this);
-    connect(timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotCallback()));
+    connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotCallback()));
     timer->start(ms, FALSE);
 }
 
